@@ -3,7 +3,7 @@ use std::{borrow::Cow, collections::HashMap, fmt::Display, hash::Hash, str::From
 use serde_json::Value;
 
 use crate::{
-    registry::{MetaSchema, MetaSchemaRef},
+    registry::{MetaSchema, MetaSchemaRef, Registry},
     types::{ParseError, ParseFromJSON, ParseResult, ToJSON, Type},
 };
 
@@ -24,6 +24,10 @@ where
             ..MetaSchema::new("object")
         }))
     }
+
+    fn register(registry: &mut Registry) {
+        V::register(registry);
+    }
 }
 
 impl<K, V> ParseFromJSON for HashMap<K, V>
